@@ -9,7 +9,7 @@ class self_employment_social_security_tax(Variable):
     unit = USD
 
     def formula(person, period, parameters):
-        rate = parameters(period).irs.self_employment.social_security_rate
+        rate = parameters(period).gov.irs.self_employment.social_security_rate
         income = person(
             "social_security_taxable_self_employment_income", period
         )
